#!/usr/bin/python3

"""
Remove old kernels.
"""

import sys
import platform
import os
import re
from subprocess import check_call


def get_version(name):
    return re.search('(\d+\.\d+\.\d+-\d+)', name).group(1)


def get_sortable_version(name):   
    numbers = filter(None, re.split('\D+', name))
    return tuple(int(n) for n in numbers)


def get_kernel_package_names(version):
    return [
        'linux-headers-{}'.format(version),
        'linux-headers-{}-generic'.format(version),
        'linux-image-{}-generic'.format(version),
        'linux-image-extra-{}-generic'.format(version),
    ]


release = platform.uname().release
assert release.endswith('-generic')
current = get_version(release)
print('Running kernel is {!r}'.format(current))

kernels = []
for name in os.listdir('/boot'):
    if name.startswith('vmlinuz-'):
        kernels.append(get_version(name))
assert current in kernels
kernels.sort(key=get_sortable_version)
print('Installed kernels:', kernels)

remove = []
for version in kernels:
    if version == current:
        break
    remove.extend(get_kernel_package_names(version))

if not remove:
    print('No old kernels to remove')
    sys.exit(0)

cmd = ['sudo', 'apt-get', '-y', 'purge'] + remove
print('Command:', cmd)
check_call(cmd)

