#!/usr/bin/python3

import os
from os import path
import tempfile
import shutil
import argparse
import sys
import subprocess
import json

parser = argparse.ArgumentParser()
parser.add_argument('--iso')
parser.add_argument('--install',
    help='Install needed dependencies and exit',
    action='store_true',
    default=False,
)
args = parser.parse_args()


def check_call(cmd):
    print(json.dumps(cmd, indent=4))
    subprocess.check_call(cmd)


if args.install:
    check_call(['sudo', 'apt-get', 'install', 
        'qemu-system-x86',
        'qemu-utils',
        'ovmf',
    ])
    sys.exit()


iso = path.abspath(args.iso)
assert path.isfile(iso)
tmp = tempfile.mkdtemp(prefix='qemu-uefi.')
img = path.join(tmp, 'vm.qcow2')
check_call(['qemu-img', 'create', '-f', 'qcow2', img, '16G'])

cmd = [
    'qemu-system-x86_64',
    '-bios', 'OVMF-pure-efi.fd', #'/usr/share/ovmf/OVMF.fd',
    '-name', 'qemu-uefi',
    '-m', '2048',
    '-enable-kvm',
    '-nodefaults',
    '-smp', '4,cores=2,threads=2,sockets=1',
    '-vga', 'std', #'qxl',
    '-drive', 'if=virtio,index=0,file={}'.format(img),
    '-net', 'user,vlan=0',
    '-net', 'nic,model=virtio,vlan=0',
    '-cdrom', iso,
]
check_call(cmd)

cmd = [
    'qemu-system-x86_64',
    '-bios', 'OVMF-pure-efi.fd', #'/usr/share/ovmf/OVMF.fd',
    '-name', 'qemu-uefi',
    '-m', '2048',
    '-enable-kvm',
    '-nodefaults',
    '-smp', '4,cores=2,threads=2,sockets=1',
    '-vga', 'std', #'qxl',
    '-drive', 'if=virtio,index=0,file={}'.format(img),
    '-net', 'user,vlan=0',
    '-net', 'nic,model=virtio,vlan=0',
]
check_call(cmd)


print(tmp)
shutil.rmtree(tmp)


