#!/usr/bin/env python

"""
Generates moinmoin markup for the "Jump in" section here:

    https://wiki.ubuntu.com/Novacut
"""

def link(url, text):
    return '[[{}|{}]]'.format(url, text)


def project_link(name):
    url = 'https://launchpad.net/' + name
    return link(url, name)


def code_link(name):
    team = ('dmedia' if name == 'filestore' else name)
    url = 'http://bazaar.launchpad.net/~{}/{}/trunk/files'.format(team, name)
    return link(url, 'Browse Code')


def bitesize_link(name):
    url = 'https://bugs.launchpad.net/{}/+bugs?field.tag=bitesize'.format(name)
    return link(url, 'Bitesize Bugs')


def reviews_link(name):
    url = 'https://code.launchpad.net/{}/+activereviews'.format(name)
    return link(url, 'Active Reviews')


assert link('https://launchpad.net/novacut', 'novacut') == \
    '[[https://launchpad.net/novacut|novacut]]'

assert project_link('novacut') == '[[https://launchpad.net/novacut|novacut]]'

assert code_link('novacut') == \
    '[[http://bazaar.launchpad.net/~novacut/novacut/trunk/files|Browse Code]]'

assert bitesize_link('novacut') == \
    '[[https://bugs.launchpad.net/novacut/+bugs?field.tag=bitesize|Bitesize Bugs]]'

assert reviews_link('novacut') == \
    '[[https://code.launchpad.net/novacut/+activereviews|Active Reviews]]'


print('')
for name in ['novacut', 'dmedia', 'microfiber', 'filestore']:
    links = [
        project_link(name),
        code_link(name),
        bitesize_link(name),
        reviews_link(name),
    ]
    text = '|| ' + ' || '.join(links) + ' ||'
    print(text)
print('')
